.. _ydoc directive_3 directive_3_2 d322:

``d322``
========

Directive 3.2.2 has a list of possible subdirectives

Subdirectives:

.. toctree::
   :maxdepth: 1

   d322/d322a
   d322/d322b


----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.